==> mkrundir-0.1.0.tar.gz: mkrundir-v0.1.0/README.md <==
# mkrundir

Create an `XDG_RUNTIME_DIR` in `/run/user/`.

This is a privileged helper that creates a runtime directory for the current
user. The directory is created in `/run/user`, and a `tmpfs` in then mounted on
it (so as to avoid persisting the directory between reboots).

## Design notes

- Using `/tmp` is racy and allows other users to hijack the directory.
- Must be explicitly called by the user (e.g.: via `~/.profile`).
- Doesn't require PAM (but doesn't conflict with it either).
- Works only on Linux due to relying capabilities(7).
- Deleting the directory on logout is out of scope.

## Requirements

- [hare](https://harelang.org) (build)

## Specification

The `XDG_RUNTIME_DIR` and its requirements are defined in the [XDG Base
Directory Specification][xdg-basedir].

[xdg-basedir]: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html

The specification requires that the directory be created upon user login, so it
is advised to call `mkrundir` in `.profile` or an equivalent mechanism early
during session start-up (notably, before services like a Wayland compositor or
the D-Bus server).

The specification also requires that the directory be deleted after a user's
last session ends. It is up to the system administrator to devise and enforce a
mechanism that enforces this. Removal of the directory is out of scope for this
tool.

Failing to remove the directory will result in a small memory usage after the
user has logged out (due to the usage of `tmpfs`, but no greater impact beyond
that).

## See also

The following tools also implement creation of this directory:

- https://github.com/jjk-jacky/pam_rundir/
- https://github.com/systemd/systemd/
- https://github.com/elogind/elogind

## Licence

This project is licensed under the ISC licence. See LICENCE for details.

==> mkrundir-0.2.0.tar.gz: mkrundir-v0.2.0/README.md <==
# mkrundir

Create an `XDG_RUNTIME_DIR` in `/run/user/`.

This is a privileged helper that creates a runtime directory for the current
user. The directory is created in `/run/user/$UID`. `/run` should be mounted as
`tmpfs`.

## Design notes

- Using `/tmp` is racy and allows other users to hijack the directory.
- Must be explicitly called by the user (e.g.: via `~/.profile`).
- Doesn't require PAM (but doesn't conflict with it either).
- On Linux, relies on capabilities(7) for privilege escalation.
- Deleting the directory on logout is out of scope (more on this below).

## Requirements

- [hare](https://harelang.org) (build)

## Specification

The `XDG_RUNTIME_DIR` and its requirements are defined in the [XDG Base
Directory Specification][xdg-basedir].

[xdg-basedir]: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html

The specification requires that the directory be created upon user login, so it
is advised to call `mkrundir` in `.profile` or an equivalent mechanism early
during session start-up (notably, before services like a Wayland compositor or
the D-Bus server).

The specification also requires that the directory be deleted after a user's
last session ends. It is up to the system administrator to devise and enforce a
mechanism that enforces this. Removal of the directory is out of scope for this
tool.

Failing to remove the directory will result in a small memory usage after the
user has logged out (due to the usage of `tmpfs`, but no greater impact beyond
that).

## See also

The following tools also implement creation of this directory:

- https://github.com/jjk-jacky/pam_rundir/
- https://github.com/systemd/systemd/
- https://github.com/elogind/elogind

## Licence

This project is licensed under the ISC licence. See LICENCE for details.
